pub struct BuildRef {
pub run_id: Uuid,
pub number: Option<i64>,
pub org: Option<String>,
pub pipeline: String,
}Expand description
Stable identity for a build, shared by BuildAccepted and hm_exec::BuildOutcome.
Local builds have a run_id only; cloud builds also have number/org.
Fields
run_id: Uuidnumber: Option<i64>org: Option<String>pipeline: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for BuildRef
impl<'de> Deserialize<'de> for BuildRef
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BuildRef, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BuildRef, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BuildRef
Sourceimpl JsonSchema for BuildRef
impl JsonSchema for BuildRef
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for BuildRef
impl Serialize for BuildRef
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for BuildRef