pub type EventStream = BoxStream<'static, BuildEvent>;Expand description
Type alias for the boxed event stream yielded by BackendHandle::into_parts.
Aliased Type
pub struct EventStream { /* private fields */ }pub type EventStream = BoxStream<'static, BuildEvent>;Type alias for the boxed event stream yielded by BackendHandle::into_parts.
pub struct EventStream { /* private fields */ }